@@ -27,7 +27,7 @@ NSE_PATH = os.path.dirname(os.path.realpath(__file__)) + '/nse/'
 NMAP_HTTP_PORTS = ['80','443','6443','8080','8443','2181'] 
 NSE_APACHE_PATH  = "+/"+os.path.dirname(os.path.realpath(__file__)) + '/nse/apache/'
 NSE_HTTP_PATH = "+/"+os.path.dirname(os.path.realpath(__file__)) + '/nse/http/'
-NSE_HTTP_SCRIPTS = ['+http-generator','+http-wordpress-enum','+http-apache-server-status','+http-server-header','http-php-version',NSE_HTTP_PATH,NSE_APACHE_PATH]
+NSE_HTTP_SCRIPTS = ['+http-generator','+http-wordpress-enum','+http-apache-server-status','+http-server-header','+http-php-version',NSE_HTTP_PATH,NSE_APACHE_PATH]
 
 NMAP_DB_PORTS = ['9200','9300','27017','27018','27019','3306','7000','7001','9042','7199','523','445','1443','6379','1521']
 NSE_DB_PATH  = "/"+os.path.dirname(os.path.realpath(__file__)) + '/nse/database/'
@@ -51,7 +51,7 @@ def build_snmp_walk_cmd(args, addr):
     if args.snmp_security_name:
         cmd = cmd + ' -v3 -u '+args.snmp_security_name
     else:
-        cmd = cmd + ' -v2c '
+        cmd = cmd + ' -v1 '
     cmd = cmd + ' -c '+args.snmp_community + ' ' + addr
     return cmd
 
@@ -250,6 +250,8 @@ def nmap_scan(args, host):
     if args.verbosity >= 3:
         logging.debug('Enabled nmap debug logging...')
         nmap_cmd = nmap_cmd + ' -vvv -d --packet-trace --reason'
+    elif args.verbosity == 2:
+        nmap_cmd = nmap_cmd + ' -vv -d '
     cmdarr = [nmap_cmd + ' ' + host]
     try:
         logging.debug("NMAP command: " + cmdarr[0])
@@ -347,7 +349,6 @@ def nmap_scan(args, host):
                             m = re.findall(version_regex, prod)
                             if m and len(m) > 0:
                                 junosver = 'juniper junos ' + [x[0] for x in m][0]
-                                ostype = 'Juniper'
                                 products.append(junosver)
                             model = prod.split(',')[1].replace('Inc.','').strip()
                             if '[' in model and ']' in model:
@@ -355,6 +356,11 @@ def nmap_scan(args, host):
                             else:
                                 model = model.split()[0].strip()
                             products.append('juniper '+model)
+                            ostype = 'Juniper'
+                        elif 'Canon' in prod:
+                            model = prod.split()[1].strip()
+                            products.append('Canon '+model)
+                            os_type = 'Canon Printer'
                         elif 'Honeywell' in prod:
                             prod = prod.replace(';',' ')
                             products.append(prod)
@@ -363,7 +369,7 @@ def nmap_scan(args, host):
                             prod = prod.split('/')[0].strip()
                             products.append(prod)
                             os_type = 'Zebra Printer'
-                        elif 'Fortinet' in prod: # try vendor specific oids
+                        elif 'Fortinet' in prod: 
                             fgosver = get_snmp_oid_value(args, cmd, '1.3.6.1.4.1.12356.101.4.1.1')
                             if fgosver: # fortios
                                 fgosver = 'fortinet fortios '+fgosver.split(',')[0].replace('v','')
@@ -376,7 +382,48 @@ def nmap_scan(args, host):
                                     if m and len(m) > 0:
                                         model = 'fortinet ' + [x[0] for x in m][0]
                                         products.append(model)
-
+                        elif 'Aruba' in prod:
+                            ostype = 'Aruba'
+                            swmodel = prod.split()[2].split('-')[0]
+                            version_regex = re.compile(r'([0-9]+\.[0-9]+\.[0-9]+)')
+                            aos_version = None
+                            m = re.findall(version_regex, prod)
+                            if m and len(m) > 0:
+                                aos_version = m[0]
+                            modelnum = re.sub("[^\d]", "", swmodel)
+                            if int(modelnum) < 6000:
+                                if aos_version:
+                                    products.append(swmodel+' arubaos-switch '+aos_version)
+                                    products.append(swmodel+' firmware '+aos_version)
+                            else:
+                                if aos_version:
+                                    products.append(swmodel+' aos-cx '+aos_version)
+                        elif 'Cisco' in prod:
+                            ostype = 'Cisco'
+                            ver = ''
+                            if 'Version' in prod:
+                                ver = prod.split('Version')[1].split()[0].strip()
+                                ver = ver.replace(',','')
+                            os_prod = None 
+                            if 'IOS' in prod:
+                                if 'XE' in prod or 'IOS-XE' in prod:
+                                    os_prod = 'cisco ios xe software '+ver
+                                else:
+                                    os_prod = 'cisco ios '+ver
+                            elif 'NX-OS(tm)' in prod:
+                                os_prod = 'cisco nx-os software '+ver
+                                device = prod.split(',')[0]
+                                if 'Nexus' in device:
+                                    device = device.replace('Nexus','Nexus ')
+                                    device = device.replace('NX-OS(tm)','')
+                                    if len(device.split()) > 3:
+                                        dlist = device.split()[:-1]
+                                        device = " ".join(dlist)
+                                    device = device + " series devices running nx-os software"
+                                    products.append(device)
+                            if os_prod:
+                                os_prod = os_prod.strip()
+                                products.append(os_prod)
                 prod = s.getAttribute('product')
                 if not prod:
                     continue
@@ -425,6 +472,8 @@ def nmap_scan(args, host):
             elif s.getAttribute('id') == 'http-php-version':
                 wpout = s.getAttribute('output')
                 if wpout != None and wpout != '':
+                    if ':' not in wpout:
+                        continue
                     prodstr = wpout.split(':')[1].strip()
                     prodstr = prodstr.split(',')[0]
                     prodstr = prodstr.split(' ')[0]
@@ -539,6 +588,10 @@ def nmap_scan(args, host):
                     if wpout not in products:
                         products.append(wpout)
                     ostype = 'Hanwha Vision'
+            elif s.getAttribute('id') == 'goanywhere_version':
+                wpout = s.getAttribute('output')
+                if wpout != None and wpout not in products:
+                    products.append(wpout)
 
         os_name_tag = None
         smb_os_name = get_smb_os(h)
