@@ -72,6 +72,7 @@ def process_compute_inventory_json(args, project_id, ci_id, ci_json):
     asset_data['products'] = plist
     asset_tags = []
     asset_tags.append('OS_RELEASE:' + asset_os)
+    asset_tags.append(asset_os)
     asset_tags.append('GCP_PROJECT:' + project_id)
     if atype == 'Google Container-Optimized OS':
         cosversion = get_cos_version(ci_json)
@@ -80,6 +81,7 @@ def process_compute_inventory_json(args, project_id, ci_id, ci_json):
     if atype is not None:
         asset_tags.append(atype)
     asset_tags.append('SOURCE:GCP')
+    asset_tags.append('GCP')
     asset_data['tags'] = asset_tags
     return asset_data
 
