@@ -2,12 +2,13 @@ import sys
 import os
 import logging
 from .gcp_cis_tool import gcp_cis as gcp_cis_tool
+from . import utils
 
 def run_gcp_cis_bench(args):
     asset = { }
     if args.assetid.strip() == "":
         logging.error("[assetid] cannot be empty")
-        sys.exit(1)
+        utils.tw_exit(1)
     asset['id'] = args.assetid
     asset['name'] = args.assetname if args.assetname and args.assetname.strip() != "" else asset['id']
     asset['type'] = 'Google Cloud Platform'
